use KinoSearch;

1;

__END__

__AUTO_XS__

{   "KinoSearch::Util::Stepper" => {
        bind_methods      => [qw( Read_Record )],
    }
}

__COPYRIGHT__

Copyright 2005-2009 Marvin Humphrey

This program is free software; you can redistribute it and/or modify
under the same terms as Perl itself.

